import Vue from 'vue'
import Vuex from 'vuex'
import { getUser, logout, getPermissions, getAllProjects, getQuestionCategory } from '@/api/base'

Vue.use(Vuex)

const store = new Vuex.Store({
  state: {
    user: {},
    permissions: [], // 权限列表
    projects: [], // 项目列表
    activeProject: {}, // 当前激活的项目
    questionCategory: [] // 试题分类
  },
  mutations: {
    setUser(state, user) {
      state.user = user
    },
    setPermissions(state, permissions) {
      state.permissions = permissions
    },
    setProject(state, projects) {
      state.projects = projects
    },
    setProjects(state, projects) {
      state.projects = projects
    },
    setActiveProjedct(state, project = {}) {
      state.activeProject = project
      localStorage.setItem('project_tag', project.tag || '')
    },
    setQuestionCategory(state, questionCategory) {
      state.questionCategory = questionCategory
    }
  },
  actions: {
    // 获取所有项目列表
    getAllProjects({ commit }) {
      getAllProjects().then(res => {
        const projects = res.data
        const localProjectTag = localStorage.getItem('project_tag')
        // 当前激活的项目
        if (localProjectTag) {
          const activeProject = projects.find(item => item.tag === localProjectTag) || {}
          commit('setActiveProjedct', activeProject)
        }
        // 所有项目列表
        commit('setProjects', projects)
      })
    },
    // 获取用户信息
    getUser({ commit }) {
      getUser().then(response => {
        commit('setUser', response)
      })
    },
    // 退出登录
    logout({ commit }) {
      return logout().then(response => {
        commit('setUser', {})
        return response
      })
    },
    async checkLogin({ commit, dispatch }) {
      const isLogin = await getUser()
        .then(response => {
          if (response.code === 0) {
            commit('setUser', response.data)
            return true
          } else {
            commit('setUser', {})
            return false
          }
        })
        .catch(() => {
          commit('setUser', {})
          return false
        })
      await dispatch('getPermissions')
      return isLogin
    },
    // 获取所有权限列表
    async getPermissions({ commit }) {
      await getPermissions().then(res => {
        if (res.data && res.data.items) {
          commit('setPermissions', res.data.items)
        }
      })
    },
    getQuestionCategory({ commit }, params) {
      return getQuestionCategory(params).then(res => {
        commit('setQuestionCategory', res.data)
        return res.data
      })
    }
  }
})

const localProjectTag = localStorage.getItem('project_tag')
// 当前激活的项目
if (localProjectTag) {
  store.commit('setActiveProjedct', { tag: localProjectTag })
}

// 初始化获取项目列表
store.dispatch('getAllProjects')

export default store
